/*
** Chameleon header file. 
** ff, 1999.
*/

#define VERSION "Chameleon 1.1 by ff"
#define MAXPATH 128

#define USAGE   "Usage: chameleon [hexrgb|color name|filename] [-t]\n\n"\
		"Examples:\n\tchameleon \"#c6c6ff\"\n\t"\
		"chameleon \"dark blue\"\n\tchameleon bigsky.jpg -t\n\n"\
		"The -t option is used only when specifying an image. It tells Chameleon\n"\
		"to tile the picture on the screen. The default behavior is to stretch it.\n\n"\
		"If no command line options are specified,\nChameleon will "\
		"go into visual control mode.\n\n"\
		"Any standard GTK command line options can also be used.\n\n"


void set_rgb(int, int, int);
int set_name(char *);
int set_file(char *, int);
void color_info(GtkWidget *, gpointer *);

